@@ -7,7 +7,7 @@ test_that("globals work", {
                  list(fleInp = "Trial_dflArg.omv", getSyn = TRUE, sveAtt = FALSE, getHTM = FALSE))
     expect_equal(fcnArg(c("merge", "data.frame")), c("x", "y", "by", "by.x", "by.y", "all", "all.x", "all.y", "sort", "suffixes", "no.dups", "incomparables", "..."))
     expect_true(chkDir(nmeOMV))
-    if (.Platform$OS.type == "unix") {
+    if (.Platform$OS.type == "unix" && Sys.getenv("NO_CHKDIR") != "true") {
         # permissions on *nix-systems
         dir.create(file.path(tempdir(), "chkPrm"), mode = "0111")
         expect_error(chkDir(file.path(tempdir(), "chkPrm", "Trial.omv")),
@@ -69,7 +69,7 @@ test_that("globals work", {
     inpDF <- jmvReadWrite::AlbumSales
     inpNme <- file.path("..", "ToothGrowth.omv")
     expect_s3_class(inp2DF(dtaInp = inpNme), "data.frame")
-    expect_equal(dim(inp2DF(dtaInp = inpNme)), c(60, 14))
+    expect_equal(dim(inp2DF(dtaInp = inpNme)), c(60, 17))
 
     inpDF <- jmvReadWrite::AlbumSales
     attr(inpDF, "fleInp") <- file.path("..", "ToothGrowth.omv")
@@ -80,12 +80,25 @@ test_that("globals work", {
     expect_s3_class(df4Chk[[1]], "data.frame")
     expect_s3_class(df4Chk[[2]], "data.frame")
     expect_equal(dim(df4Chk[[1]]), c(200, 5))
-    expect_equal(dim(df4Chk[[2]]), c(60, 14))
+    expect_equal(dim(df4Chk[[2]]), c(60, 17))
     expect_equal(names(df4Chk[[1]]), c("selSbj", "Adverts", "Airplay", "Image", "Sales"))
-    expect_equal(names(df4Chk[[2]]), c("Filter 1", "ID", "logLen", "supp - Transform 1", "len", "supp", "dose", "dose2", "Trial", "Residuals", "J", "K", "L", "weights"))
+    expect_equal(names(df4Chk[[2]]), c("Filter 1", "ID", "logLen", "supp - Transform 1", "len", "supp", "dose", "dose2", "dose3", "Trial", "Residuals", "J", "K", "L", "M", "O", "weights"))
     expect_equal(names(attributes(df4Chk[[1]])), c("datalabel", "names", "var.labels", "class", "row.names", "fleInp"))
     expect_equal(attr(df4Chk[[1]], "fleInp"), file.path("..", "ToothGrowth.omv"))
 
+    inpDF <- rbind(jmvReadWrite::AlbumSales[seq(sample(10)), ] * NA, jmvReadWrite::AlbumSales, jmvReadWrite::AlbumSales[seq(sample(10)), ] * NA)
+    df4Chk <- inp2DF(dtaInp = inpDF, rmvEmp = TRUE)
+    expect_s3_class(df4Chk, "data.frame")
+    expect_equal(dim(df4Chk), c(200, 5))
+    expect_equal(names(df4Chk), c("selSbj", "Adverts", "Airplay", "Image", "Sales"))
+    expect_equal(names(attributes(df4Chk)), c("names", "row.names", "class"))
+    expect_true(all(df4Chk == jmvReadWrite::AlbumSales))
+
+    inpDF <- rbind(jmvReadWrite::AlbumSales[seq(sample(10)), ] * NA, jmvReadWrite::AlbumSales[seq(1, 100), ], jmvReadWrite::AlbumSales[1, ] * NA,
+                   jmvReadWrite::AlbumSales[seq(101, 200), ], jmvReadWrite::AlbumSales[seq(sample(10)), ] * NA)
+    expect_error(df4Chk <- inp2DF(dtaInp = inpDF, rmvEmp = TRUE),
+      regexp = "Empty rows are not permitted execpt from the begin or the end of an input data frame \\(in such case, they are automatically removed\\)\\.")
+
     tmpDF <- data.frame(ID = sprintf("P_%04d", sample(9999, 100)), I = as.integer(sample(1e6, 100)), D = rnorm(100),
                         OT = factor(sample(c("low", "middle", "high"), 100, replace = TRUE), levels = c("low", "middle", "high"), ordered = TRUE),
                         ON = factor(sample(seq(7), 100, replace = TRUE), levels = seq(7), ordered = TRUE),
@@ -96,7 +109,7 @@ test_that("globals work", {
     attr(tmpDF[["ON"]], "values")   <- seq(7)
     attr(tmpDF[["NN"]], "values")   <- seq(7)
     attr(tmpDF[["CR"]], "jmv-desc") <- "Trial (is description kept?)"
-    expect_equal(sapply(sapply(jmvAtt(tmpDF), attributes), names), list(ID = c("jmv-id", "measureType", "dataType"),
+    expect_equal(lapply(lapply(jmvAtt(tmpDF), attributes), names), list(ID = c("jmv-id", "measureType", "dataType"),
         I = c("measureType", "dataType"), D = c("measureType", "dataType"),
         OT = c("levels", "class", "measureType", "dataType"), ON = c("levels", "class", "values", "measureType", "dataType"),
         NT = c("levels", "class", "measureType", "dataType"), NN = c("levels", "class", "values", "measureType", "dataType"),
